@@ -7,13 +7,21 @@ summary.GDINA <-
     output <- list("Loglikelihood"=extract(object,"logLik"),
     "Deviance"=extract(object,"deviance"),
     "AIC"=extract(object,"AIC"),
-    "AIC Penalty"=2*extract(object,"npar"),
+    "AIC penalty"=2*extract(object,"npar"),
     "AIC penalty due to item parameters"=2*extract(object,"npar.item"),
     "AIC penalty due to population parameters"=2*extract(object,"npar.att"),
     "BIC"=extract(object,"BIC"),
     "BIC penalty"=log(extract(object,"nobs"))*extract(object,"npar"),
     "BIC penalty due to item parameters"=log(extract(object,"nobs"))*extract(object,"npar.item"),
     "BIC penalty due to population parameters"=log(extract(object,"nobs"))*extract(object,"npar.att"),
+    "CAIC"=extract(object,"CAIC"),
+    "CAIC penalty"=log(extract(object,"nobs")+1)*extract(object,"npar"),
+    "CAIC penalty due to item parameters"=log(extract(object,"nobs")+1)*extract(object,"npar.item"),
+    "CAIC penalty due to population parameters"=log(extract(object,"nobs")+1)*extract(object,"npar.att"),
+    "SABIC"=extract(object,"SABIC"),
+    "SABIC penalty"=log((extract(object,"nobs")+2)/24)*extract(object,"npar"),
+    "SABIC penalty due to item parameters"=log((extract(object,"nobs")+2)/24)*extract(object,"npar.item"),
+    "SABIC penalty due to population parameters"=log((extract(object,"nobs")+2)/24)*extract(object,"npar.att"),
     "Attribute Prevalence"=extract(object,"prevalence"),
     "ngroup"=extract(object,"ngroup"),
     "Number of parameters"=extract.GDINA(object,"npar"),
